summaryrefslogtreecommitdiff
path: root/jstests/libs/override_methods/validate_collections_on_shutdown.js
diff options
context:
space:
mode:
Diffstat (limited to 'jstests/libs/override_methods/validate_collections_on_shutdown.js')
-rw-r--r--jstests/libs/override_methods/validate_collections_on_shutdown.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/jstests/libs/override_methods/validate_collections_on_shutdown.js b/jstests/libs/override_methods/validate_collections_on_shutdown.js
index a1e56fd1ca8..a378d6e390a 100644
--- a/jstests/libs/override_methods/validate_collections_on_shutdown.js
+++ b/jstests/libs/override_methods/validate_collections_on_shutdown.js
@@ -29,8 +29,8 @@ MongoRunner.validateCollectionsCallback = function(port) {
return;
}
- // Set slaveOk=true so that we can run commands against any secondaries.
- conn.setSlaveOk();
+ // Set secondaryOk=true so that we can run commands against any secondaries.
+ conn.setSecondaryOk();
let dbNames;
let result =